/* Encrypted password support */
#undef PAM_SMB_ENC_PASS

/* Message queue permissions, root or anyone */
#undef PAM_SMB_ROOT_ONLY

/* Daemon support */
#undef PAM_SMB_DAEMON

/* Has LOG_AUTHPRIV or LOG_AUTH */
#undef USE_LOGAUTH

/* Has LIBCRYPT */
#undef HAVE_LIBCRYPT

#ifdef USE_LOGAUTH
#define LOG_AUTHPRIV (4<<3)
#endif

/* DB_DIR defines where to put DB cache file and map temp files */
#undef DB_DIR
